@@ -3,10 +3,11 @@ use crate::structs::*;
 use aes_gcm::aead::{Aead, NewAead};
 use aes_gcm::{Aes256Gcm, Key, Nonce};
 use anyhow::{Context, Ok, Result};
+use argon2::Argon2;
+use argon2::Params;
 use rand::{prelude::StdRng, Rng, RngCore, SeedableRng};
 use sha3::Digest;
 use sha3::Sha3_512;
-use std::num::NonZeroU32;
 use std::time::Instant;
 use std::{
     fs::{metadata, File},
@@ -72,13 +73,8 @@ pub fn encrypt_file(input: &str, output: &str, keyfile: &str, sha_sum: bool) ->
 
     let start_time = Instant::now();
 
-    ring::pbkdf2::derive(
-        ring::pbkdf2::PBKDF2_HMAC_SHA512,
-        NonZeroU32::new(122880).unwrap(),
-        &salt,
-        &raw_key,
-        &mut key,
-    );
+    let argon2 = Argon2::new(argon2::Algorithm::Argon2id, argon2::Version::V0x13, Params::default());
+    argon2.hash_password_into(&raw_key, &salt, &mut key).expect("Unable to hash your password with argon2");
 
     let nonce_bytes = rand::thread_rng().gen::<[u8; 12]>();
     let nonce = Nonce::from_slice(nonce_bytes.as_slice());
@@ -111,7 +107,6 @@ pub fn encrypt_file(input: &str, output: &str, keyfile: &str, sha_sum: bool) ->
         let hash = hasher.finalize();
         let hash_b64 = base64::encode(hash);
         println!("Hash of the encrypted file is: {}", hash_b64);
-        println!("Write this down for later verification - it is not for security, but to ensure your file is exactly how it was in the first place.");
     }
 
     Ok(())
